@@ -32,7 +32,7 @@ logger = logging.getLogger(__name__)
 
 class SqlCreds:
     """
-    Credential object for all SQL operations. Will automatically also create a SQLAlchemy 
+    Credential object for all SQL operations. Will automatically also create a SQLAlchemy
     engine that uses `pyodbc` as the DBAPI, and store it in the `self.engine` attribute.
 
     If `username` and `password` are not provided, `with_krb_auth` will be `True`.
@@ -46,11 +46,11 @@ class SqlCreds:
     username : str, optional
     password : str, optional
     driver_version : int, default 17
-        The version of the Microsoft ODBC Driver for SQL Server to use 
+        The version of the Microsoft ODBC Driver for SQL Server to use
     odbc_kwargs : dict of {str, str or int}, optional
-        additional keyword arguments, to pass into ODBC connection string, 
+        additional keyword arguments, to pass into ODBC connection string,
         such as Encrypted='yes'
-    
+
     Returns
     -------
     `bcpandas.SqlCreds`
@@ -105,10 +105,10 @@ class SqlCreds:
     @classmethod
     def from_engine(cls, engine: sa.engine.base.Engine) -> "SqlCreds":
         """
-        Alternate constructor, from a `sqlalchemy.engine.base.Engine` that uses `pyodbc` as the DBAPI 
+        Alternate constructor, from a `sqlalchemy.engine.base.Engine` that uses `pyodbc` as the DBAPI
         (which is the SQLAlchemy default for MS SQL) and using an exact PyODBC connection string (not DSN or hostname).
         See https://docs.sqlalchemy.org/en/13/dialects/mssql.html#connecting-to-pyodbc for more.
-        
+
         Parameters
         ----------
         engine : `sqlalchemy.engine.base.Engine`
@@ -284,7 +284,10 @@ def _prepare_table(
 
 
 def _validate_args(
-    df: pd.DataFrame, sql_type: str, if_exists: str, batch_size: Optional[int],
+    df: pd.DataFrame,
+    sql_type: str,
+    if_exists: str,
+    batch_size: Optional[int],
 ) -> None:
     assert sql_type == TABLE, "only supporting table, not view, for now"
     assert if_exists in IF_EXISTS_OPTIONS
@@ -318,6 +321,8 @@ def to_sql(
     dtype: dict = None,
     process_dest_table: bool = True,
     print_output: bool = True,
+    delimiter: str = None,
+    quotechar: str = None,
 ):
     """
     Writes the pandas DataFrame to a SQL table or view.
@@ -346,7 +351,7 @@ def to_sql(
         * fail: Raise a BCPandasValueError.
         * replace: Drop the table before inserting new values.
         * append: Insert new values to the existing table. Matches the dataframe columns to the database columns by name.
-            If the database table exists then the dataframe cannot have new columns that aren't in the table, 
+            If the database table exists then the dataframe cannot have new columns that aren't in the table,
             but conversely table columns can be missing from the dataframe.
 
     batch_size : int, optional
@@ -366,6 +371,15 @@ def to_sql(
     print_output: bool, default True
         Whether to print output to STDOUT in real time. Regardless, the output will be logged.
         Added in version 1.3
+    delimiter: str, default None
+        Optional delimiter to use, otherwise will use the result of `constants.get_delimiter`
+    quotechar: str, default None
+        Optional quotechar to use, otherwise will use the result of `constants.get_quotechar`
+
+    Notes
+    -----
+    If `delimiter` and/or `quotechar` are specified, you must ensure that those characters
+    are not present in the actual data.
     """
     # validation
     if df.shape[0] == 0 or df.shape[1] == 0:
@@ -377,8 +391,8 @@ def to_sql(
     if index:
         df = df.copy(deep=True).reset_index()
 
-    delim = get_delimiter(df)
-    quotechar = get_quotechar(df)
+    delim = get_delimiter(df) if delimiter is None else delimiter
+    _quotechar = get_quotechar(df) if quotechar is None else quotechar
 
     # save to temp path
     csv_file_path = get_temp_file()
@@ -389,7 +403,7 @@ def to_sql(
         header=False,
         index=False,  # already set as new col earlier if index=True
         quoting=csv.QUOTE_MINIMAL,  # pandas default
-        quotechar=quotechar,
+        quotechar=_quotechar,
         line_terminator=NEWLINE,
         doublequote=True,
         escapechar=None,  # not needed, as using doublequote
